#
# spec file for package jeos-firstboot
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%if 0%{?suse_version} >= 1550
%bcond_with rpiwifi
%else
%bcond_without rpiwifi
%endif

Name:           jeos-firstboot
Version:        1.5.0
Release:        1.1
Summary:        Simple text based JeOS first boot wizard
License:        MIT
Group:          Development/Tools/Other
URL:            https://github.com/openSUSE/jeos-firstboot
Source0:        %{name}-%{version}.tar.xz
BuildRequires:  systemd-rpm-macros
Requires:       dialog
Requires:       iproute2
Requires:       live-langset-data
Requires:       timezone
# Very useful on distros which disable pw-based root login per ssh
%if 0%{?suse_version} >= 1550
Requires:       ssh-pairing
%endif
Requires:       ((/usr/bin/qrencode and /usr/bin/oathtool) if pam_oath)
Requires:       (/usr/bin/nmtui if NetworkManager)
BuildArch:      noarch
%{?systemd_requires}

%description
Simple text based JeOS first boot wizard that can be used instead
of the line based one that is built into systemd.

%package rpiwifi
Summary:        jeos-firstboot module for WiFi configuration for RaspberryPi systems
Group:          Productivity/Networking/Other
Requires:       %{name} = %{version}
Requires:       wicked
Requires:       wireless-tools
Requires:       wpa_supplicant

%description rpiwifi
This module hooks into jeos-firstboot and allows the user to enter data to connect
his RaspberryPi system to a wireless network.

%prep
%setup -q

%build

%install
cp -a files/* %{buildroot}
%if %{without rpiwifi}
rm %{buildroot}%{_datadir}/jeos-firstboot/modules/raspberrywifi
%endif

%preun
%service_del_preun jeos-firstboot.service

%postun
%service_del_postun jeos-firstboot.service

%pre
%service_add_pre jeos-firstboot.service

%post
%service_add_post jeos-firstboot.service

%files
%doc README.md
%license LICENSE
%{_unitdir}/jeos-firstboot.service
%{_unitdir}/jeos-firstboot-snapshot.service
%dir %{_datadir}/defaults/
%{_datadir}/defaults/jeos-firstboot.conf
%dir %{_datadir}/jeos-firstboot/
%dir %{_datadir}/jeos-firstboot/modules/
%{_datadir}/jeos-firstboot/modules/network
%dir %{_datadir}/jeos-firstboot/modules/network-modules/
%{_datadir}/jeos-firstboot/modules/network-modules/NetworkManager
%{_datadir}/jeos-firstboot/modules/network-modules/wicked
%{_datadir}/jeos-firstboot/modules/{ssh_enroll,status_mail,otp,user}
%{_sbindir}/jeos-config
%{_sbindir}/jeos-firstboot
%{_sbindir}/jeos-firstboot-snapshot
%{_datadir}/jeos-firstboot/jeos-firstboot-dialogs
%{_datadir}/jeos-firstboot/jeos-firstboot-functions
%{_datadir}/jeos-firstboot/welcome-screen

%if %{with rpiwifi}
%files rpiwifi
%{_datadir}/jeos-firstboot/modules/raspberrywifi
%endif

%changelog
* Wed Aug  7 2024 Fabian Vogt <fvogt@suse.com>
- Update to version 1.5.0:
  * Add module for TOTP setup (jsc#CPT-84)
  * Add module for user creation
  * Set LC_COLLATE=C.UTF-8
  * Document module API in README.md
  * Let modules specify title, description and priority
  * jeos-firstboot-functions: Simplify _find_modules
  * Use tabs for indentation everywhere
  * Drop stale README file
* Fri May 24 2024 Fabian Vogt <fvogt@suse.com>
- Update to version 1.4.3:
  * Use UTC as default TZ if there was no locale selection dialog (boo#1224212)
* Mon May  6 2024 Fabian Vogt <fvogt@suse.com>
- Update to version 1.4.2:
  * Resolve cycle w.r.t. wicked (bsc#1223391)
* Mon Apr 29 2024 Fabian Vogt <fvogt@suse.com>
- Make ssh-pairing a required dep on new distros
* Wed Apr 17 2024 Fabian Vogt <fvogt@suse.com>
- Update to version 1.4.1:
  * Add ssh_enroll module
* Thu Apr 11 2024 Fabian Vogt <fvogt@suse.com>
- Update to version 1.4.0:
  * Use d_styled in more places
  * Add support for systemd credentials
  * Order modules, read from /etc
* Wed Mar 27 2024 Fabian Vogt <fvogt@suse.com>
- Update to version 1.3.0.8:
  * Match CPE_NAME for checking whether to show the registration dialog (bsc#1222034)
* Thu Mar 14 2024 Fabian Vogt <fvogt@suse.com>
- Update to version 1.3.0.7:
  * Only skip jeos-firstboot if cloud-init found a config source (bsc#1220281)
* Tue Feb 20 2024 Fabian Vogt <fvogt@suse.com>
- Update to version 1.3.0.6:
  * Show transactional-update register if needed (bsc#1219949)
  * Don't show confirmation dialog when exiting jeos-config
  * Refactor dialog helpers in jeos-firstboot-functions
* Mon Jan 22 2024 Fabian Vogt <fvogt@suse.com>
- Update to version 1.3.0.3:
  * status_mail: Rerun status-mail-generator after saving
* Mon Jan 22 2024 Fabian Vogt <fvogt@suse.com>
- Update to version 1.3.0.2:
  * status_mail: Add a field for MAILX_OPTIONS as well
  * status_mail: Fix RELAYHOST option
* Thu Jan 18 2024 Fabian Vogt <fvogt@suse.com>
- Update to version 1.3.0.0:
  * Add status_mail module for systemd-status-mail configuration
    (jsc#PED-6989)
  * Apply automatic shellcheck fixes
  * Add annotations for shellcheck
  * Load files based on jeos-firstboot/jeos-config location
* Thu Nov 30 2023 jeos-internal@suse.de
- Update to version 1.2.0.9:
  * Add KeyringMode=shared
* Tue Aug 22 2023 Fabian Vogt <fvogt@suse.com>
- Update to version 1.2.0.7:
  * Don't pass --setup-machine-id to systemd-firstboot
* Wed May 10 2023 Fabian Vogt <fvogt@suse.com>
- Update to version 1.2.0.6:
  * Change EULA/license dialog button label to "Continue" (bsc#1210279)
- Only build the rpiwifi package on SLE/Leap 15 (bsc#1207419)
- Add an explicit dependency on nmtui
* Thu Mar  9 2023 jeos-internal@suse.de
- Update to version 1.2.0.5:
  * Support /usr/lib/os-release (#102)
* Mon Jun 20 2022 Ludwig Nussel <lnussel@suse.de>
- Don't require wicked nor NetworkManager. Both are optional
* Mon Jun 20 2022 Fabian Vogt <fvogt@suse.com>
- Update to version 1.2.0.4:
  * Rewrite license code
* Tue Jun 14 2022 Fabian Vogt <fvogt@suse.com>
- Update to version 1.2.0.3:
  * Don't ask for licence confirmation if not needed
  * Deduplicate wifi list
* Thu Apr 14 2022 Fabian Vogt <fvogt@suse.com>
- Update to version 1.2.0:
  * Make use of SPDX identifiers
  * Read dialog output into a variable directly
  * Drop broken error handling for dialog
  * Fix dialog asking about wicked network reconfiguration
  * Start nmtui in jeos-firstboot if no active connection could be detected
  * Load network modules dynamically
  * Only list applicable modules in jeos-config
  * Convert network configuration to a module
  * Fix size of the "No root password set" dialog
* Wed Mar 16 2022 Fabian Vogt <fvogt@suse.com>
- Update to version 1.1.1.1:
  * Quick'n'dirty NetworkManager support
- Switch git URL to https
- Require NetworkManager or wicked
* Thu Feb 17 2022 Fabian Vogt <fvogt@suse.com>
- Update to version 1.1.1.0:
  * Drop use of /var/log/jeos
  * Avoid "Terminated console_subproc" message from wait
  * Skip broken consoles (bsc#1195975)
* Thu Feb  3 2022 Fabian Vogt <fvogt@suse.com>
- Update to version 1.1.0.3:
  * Don't make a snapshot if /etc is not part of it
  * Use mountpoint with -q
  * Don't attach jeos-firstboot-snapshot.service to the TTY
* Thu Jan 20 2022 Fabian Vogt <fvogt@suse.com>
- Update to version 1.1.0.0:
  * Introduce welcome screen for console switching
    (boo#1184157, jsc#SLE-18306)
  * Drop redundant functions in jeos-firstboot-functions
  * Drop call to snapper setup-quota, kiwi does that meanwhile
* Tue Aug 17 2021 Guilherme Moro <gmoro@suse.com>
- Include appropriate Requires
  * wicked
  * iptroute2
  * timezone
* Fri Jul  9 2021 jeos-internal@suse.de
- Update to version 1.0.2.0:
  * Skip the lo interface when probing for DHCP
- Use @TAG_OFFSET@ in version to make it unambiguous
* Thu May  6 2021 jeos-internal@suse.de
- Update to version 1.0.1:
  * Always show manual SSID option
  * Call dialog with --backtitle everywhere
  * Calculate the height of menus dynamically (bsc#1177188)
  * Create README.md
* Mon Mar  1 2021 Fabian Vogt <fvogt@suse.com>
- Fix git url in _service
* Thu Feb 25 2021 jeos-internal@suse.de
- Update to version 1.0.0:
  * Use race-free DBus API to silence systemd (bsc#1119382)
  * Implement separate configuration for wifi (bsc#1156775)
  * Major refactoring and final version of jeos-config (bsc#1181957)
* Thu Aug 27 2020 jeos-internal@suse.de
- Update to version 0.0+git20200827.e920a15:
  * Drop the info dialog about glibc-locale (jsc#SLE-15348)
* Fri May  8 2020 jeos-internal@suse.de
- Update to version 0.0+git20200508.d0ccd48:
  * Move scripts to /usr/sbin
* Tue Mar 31 2020 jeos-internal@suse.de
- Update to version 0.0+git20200331.db3bc7c:
  * Don't set JEOS_HIDE_SUSECONNECT by default
* Thu Mar 26 2020 jeos-internal@suse.de
- Update to version 0.0+git20200326.f1f96e3:
  * Add JEOS_HIDE_SUSECONNECT option
* Mon Mar  9 2020 jeos-internal@suse.de
- Update to version 0.0+git20200309.b23a6ef:
  * Add JEOS_EULA_ALREADY_AGREED option
* Wed Feb 26 2020 jeos-internal@suse.de
- Update to version 0.0+git20200226.95cfe28:
  * Show license on openSUSE as well (bsc#1164583)
  * Improve variable names on net config
  * Fix EULA message position
  * Fix comments typo
  * Improve coding style
* Wed Nov 27 2019 jeos-internal@suse.de
- Update to version 0.0+git20191127.be35ecb:
  * Improve Rpi wireless config, jsc#SLE-10603
  * Disable exit on error during dialog execution
  * Clarify comment about localectl list-keymaps
* Mon Oct 21 2019 jeos-internal@suse.de
- Update to version 0.0+git20191021.66ccca7:
  * Fix skipping duplicate locale and keyboard layout dialogs (bsc#1154638)
* Fri Oct 11 2019 jeos-internal@suse.de
- Update to version 0.0+git20191011.0754638:
  * SUSEConnect: do not show the register dialog on non-SLE distributions
* Wed Oct  9 2019 jeos-internal@suse.de
- Update to version 0.0+git20191009.5daf1fd:
  * Ignore udevadm and modprobe errors for use in containers
* Thu Aug  8 2019 jeos-internal@suse.de
- Update to version 0.0+git20190808.4b6ff0b:
  * Ignore systemd-user-sessions in jeos-firstboot-snapshot.service
* Wed Jul 24 2019 jeos-internal@suse.de
- Update to version 0.0+git20190724.7f3b281:
  * Set DHCLIENT(6)_SET_HOSTNAME=yes in sysconfig/network/dhcp
  * Remove examples dir
  * Remove useless rm
  * Move snapshot creation into a separate service (bsc#1129730)
* Fri Jul  5 2019 jeos-internal@suse.de
- Update to version 0.0+git20190705.e2889c3:
  * Don't run jeos-firstboot.service if cloud-init is active (jsc#SLE-7254)
  * Do not fail when updating bootloader in no-UEFI
* Thu May 23 2019 jeos-internal@suse.de
- Update to version 0.0+git20190523.f1f2bfa:
  * Fix broken function call in raspberrywifi, simplify
  * Don't overwrite WiFi interface config
  * Don't overwrite the cleanup trap
  * Fix whitespace
  * Don't use "if d", it never returns false
  * Skip WiFi interface selection if there's only one
  * Ignore setterm -msg failure
  * Don't read stderr from dialog, use --output-fd instead
  * Clean and fix raspberrywifi
  * Fix module hook execution
  * Fix warning on startup
  * Fix typos/clarify comments in jeos-firstboot.conf
  * Remove shebang and empty line in raspberrywifi
* Tue May 21 2019 jeos-internal@suse.de
- Update to version 0.0+git20190521.23bc1d3:
  * is_raspberry: do not show grep errors in non-rpi
  * Configure all interfaces that resolves
  * Allow to skip certain steps by setting values in a configuration file
  * Execute external script(s) on firstboot
- Split module for WiFi configuration into subpackage
* Wed Apr 17 2019 jeos-internal@suse.de
- Update to version 0.0+git20190417.7ba1ac9:
  * Only configure snapper quota if no btrfs qgroups exist yet
* Tue Apr 16 2019 jeos-internal@suse.de
- Update to version 0.0+git20190416.7a667ec:
  * reenable console loglevel to the default
* Tue Mar 19 2019 jeos-internal@suse.de
- Update to version 0.0+git20190319.e7555da:
  * Use the base symlink for the new location
  * Correct if statement coding style
  * Remove unneeded comment from new if block
  * Test if snapper exists before trying to run it
* Fri Mar 15 2019 jeos-internal@suse.de
- Update to version 0.0+git20190315.4a7660d:
  * Support the non-standard and hopefully temporary location for the SLE EULAs
    (works around jsc#SLE-3067 and fixes bsc#1127166)
* Fri Feb 22 2019 opensuse-packaging@opensuse.org
- Update to version 0.0+git20190222.ccc0ad8:
  * Fix backtitle of license agreement regression
* Wed Feb 13 2019 opensuse-packaging@opensuse.org
- Update to version 0.0+git20190213.3c01127:
  * Less warnings, fix license decline dialog
  * Do not fail on wireless setup
  * Avoid systemd output on the screen, bsc#1119382
  * Check wlan adaptor presence, bsc#1122901
* Fri Dec  7 2018 opensuse-packaging@opensuse.org
- Update to version 0.0+git20181207.6b889b0:
  * Implement review comments
  * run wifi config in the end
  * Deal with file security for wifi config
  * Create confirmation dialog for exiting
  * quote comparing variables to avoid errors
  * Overall implementation of commands and flow
* Thu Oct 25 2018 opensuse-packaging@opensuse.org
- Update to version 0.0+git20181025.0848274:
  * Fix setting the locale
  * Fix reading the default timezone if /etc/localtime is a relative symlink
* Fri Oct 12 2018 opensuse-packaging@opensuse.org
- Update to version 0.0+git20181008.086fc72:
  * Prefix more commands with "run" to allow test runs as non-root
  * Only list locales which glibc has information about
* Thu Aug  9 2018 opensuse-packaging@opensuse.org
- Update to version 0.0+git20180808.85a2c03:
  * Get list of locales from /usr/share/langset/ and remove duplicate "us" keymap
* Fri Aug  3 2018 opensuse-packaging@opensuse.org
- Update to version 0.0+git20180803.c9090ae:
  * Remove jeos-add-repos, superseded by the live-add-yast-repos package
- Added dialog as Requires
- Clean spec file and drop unnecessary BuildRequires
* Wed Aug  1 2018 opensuse-packaging@opensuse.org
- Update to version 0.0+git20180801.e679773:
  * Don't print errors if plymouth is not installed (bsc#1101879)
  * Don't switch to the choosen LANG before fbiterm/kmscon is started
  * Replace "tty" call with "ps h -o tty"
  * Remove kmscon_localed, now part of upstream kmscon
  * Fallback to fbiterm if kmscon not available
  * Don't start kmscon on serial consoles
  * Improve kmscon call
  * kmscon integration
* Fri Jun 15 2018 opensuse-packaging@opensuse.org
- Update to version 0.0+git20180615.258b566:
  * make jeos-firstboot.service closer to YaST2-Firstboot.service
  * Use own canary file instead of ConditionFirstBoot to allow reconfiguration (bsc#1097630)
  * Use live-langset-data to setup locale settings during runtime (bsc#1096556)
* Fri May 25 2018 opensuse-packaging@opensuse.org
- Update to version 0.0+git20180525.280836a:
  * Rework locale selection
  * Map console fonts for non-latin locale,bsc#1094346
  * Also check for license filenames with the locale's UTF-8 suffix stripped
* Wed May 16 2018 opensuse-packaging@opensuse.org
- Update to version 0.0+git20180516.d5031a7:
  * Run sevice before systemd-tmpfiles, bsc#1092132
* Thu Apr 26 2018 opensuse-packaging@opensuse.org
- Update to version 0.0+git20180425.76e5ff7:
  * Turn off systemd status output while jeos-firstboot is running
* Fri Apr  6 2018 opensuse-packaging@opensuse.org
- Update to version 0.0+git20180406.e01f473:
  * Setup quota for btrfs, fix bsc#1087079
* Tue Mar 13 2018 opensuse-packaging@opensuse.org
- Update to version 0.0+git20180313.313b2ea:
  * Remove dracut initrd regeneration, bsc#1084161
  * Remove obsolete kiwi hook, bsc#1084160
* Thu Jan 11 2018 opensuse-packaging@opensuse.org
- Update to version 0.0+git20180111.c39e31f:
  * append to vconsole.conf instead of overwriting
* Fri Nov 24 2017 opensuse-packaging@opensuse.org
- Update to version 0.0+git20171124.eead2bd:
  * Change default values for ifcfg files bsc#1069782
* Mon Nov 13 2017 opensuse-packaging@opensuse.org
- Update to version 0.0+git20171113.02e973c:
  * change initial snapshot number to 2
  * Run dracut before initial snapshot
* Wed Oct 25 2017 opensuse-packaging@opensuse.org
- Update to version 0.0+git20171024.4c4ec65:
  * Add require for snapshots mount point
  * Initial network configuration fixes bsc#1061829
* Tue Jul  4 2017 lnussel@suse.de
- Update to version 0.0+git20170629.77ff28f:
  * Add udev-settle to wait all udev rules to be run
  * Provide default values for LINES and COLUMNS
  * Check if booted through EFI to fix yast bootloader
  * fixes after review
* Fri Mar 17 2017 fvogt@suse.com
- Update to version 0.0+git20170317.c20e917:
  * Use same dependencies as systemd-firstboot.service
* Fri Mar 10 2017 fvogt@suse.com
- Update to version 0.0+git20170310.18283bf:
  * Replace jeos-tool with jeos-add-repos script
  * Move jeos-add-repos to sbin
* Tue Mar  7 2017 fvogt@suse.com
- Update to version 0.0+git20170307.f650718:
  * Add [Install] section to jeos-firstboot.service
* Thu Jan 19 2017 lnussel@suse.de
- add license to file list
* Wed Nov 30 2016 lnussel@suse.de
- Update to version 0.0+git20161130.db63ad6:
  * Add LICENSE
  * Add README
  * Move ifcfg-eth0 to examples
  * Don't package service symlinks
* Fri Sep 16 2016 mkravec@suse.com
- Update to version 0.0+git20160916.ce20b59:
  * Fix jeos-tool typo
* Fri Sep 16 2016 mkravec@suse.com
- Update to version 0.0+git20160915.bd90972:
  * conflict with emergency.service
  * adjust for new kiwi
  * rename snapshot 1 to match normal SLE's
  * Create read-only snapshots
  * Set dialog heigh
  * Set kernel logging to warning
  * Apply changes from Matthias and disable timeline creation
  * Use jeos-tool to add repositories
  * Add comments
* Wed Sep 14 2016 mkravec@suse.com
- Update to version 0.0+git20160720.7177a42:
  * add tool to generate zypp repos from control.xml
  * fix copyright holder
  * conflict with emergency.service
  * adjust for new kiwi
  * rename snapshot 1 to match normal SLE's
  * Create read-only snapshots
  * Set dialog heigh
  * Set kernel logging to warning
  * Apply changes from Matthias and disable timeline creation
* Thu Sep  1 2016 mkravec@opensuse.org
- Update to version 0.0+git20160901.d14f112:
  * Removed jeos-tool
* Thu Sep  1 2016 mkravec@opensuse.org
- Update to version 0.0+git20160720.7177a42:
  * add tool to generate zypp repos from control.xml
  * fix copyright holder
  * conflict with emergency.service
  * adjust for new kiwi
  * rename snapshot 1 to match normal SLE's
  * Create read-only snapshots
  * Set dialog heigh
  * Set kernel logging to warning
  * Apply changes from Matthias and disable timeline creation
* Wed Dec  9 2015 rbrownsuse@opensuse.org
- Update to version 0.0+git20151209.591a818:
  + Scripted reset/update of openSUSE jeos-firstboot based on SLE jeos-firstboot
* Wed Nov 18 2015 lnussel@suse.de
- Update to version 0.0+git20151118.ee47f82:
  + remove 70-persistent-net.rules
  + Only show the SLES specific 'SUSEConnect' dialog if running SLES
  + fix dryrun
  + check for SUSEConnect instead of triggering on SLE
  + don't prompt EULA on openSUSE
  + prompt for locale first
  + prepare to localize
  + use localized eula file
  + mark snapshots for cleanup (bsc#949674)
* Wed Sep 30 2015 lnussel@suse.de
- Update to version 0.0+git20150930.4398233:
  + don't try to create snapshot 2 again
  + another attempt to fix boot dependencies (bnc#947815)
  + halt doesn't really work. add loop instead
* Mon Sep 28 2015 lnussel@suse.de
- Update to version 0.0+git20150925.7abb8f2:
  + tune ordering of the service a bit
  + call vconsole setup again
  + apply keyboard and locale before prompting for the password
  + move firstboot before colplug
  + update description
* Wed Sep 23 2015 lnussel@suse.de
- Update to version 0.0+git20150923.a897cec:
  + add kiwi hook to create snapshot
  + create snapshot after firstboot
  + start debug shell if no root password set
* Tue Sep 22 2015 lnussel@suse.de
- Update to version 0.0+git20150922.ebc74de:
  + fix dryrun
  + don't modify etc/motd
* Tue Sep 22 2015 lnussel@suse.de
- Update to version 0.0+git20150922.797a443:
  + eula and error handling
  + get rid of bashrc
  + switch of kernel message spamming
  + always use utf8 locales
  + set RC_LANG in sysconfig
  + confirm root password
  + snapper doesn't work in firstboot o_O
  + password workaround
  + try snapper
  + don't call snapper, useless anyways
* Tue Sep 22 2015 lnussel@suse.de
- initial package
